@@ -55,8 +55,8 @@ class TxHistoryController(QObject):
         sources_service,
     ):
 
-        transfer = TransferController.integrate_to_main_view(None, app, connection)
-        view = TxHistoryView(parent.view, transfer.view)
+        controller = TransferController.integrate_to_main_view(None, app, connection)
+        view = TxHistoryView(parent.view, controller.view)
         model = TxHistoryModel(
             None,
             app,
@@ -66,14 +66,14 @@ class TxHistoryController(QObject):
             transactions_service,
             sources_service,
         )
-        txhistory = cls(view, model, transfer)
+        txhistory = cls(view, model, controller)
         model.setParent(txhistory)
         app.referential_changed.connect(txhistory.refresh_balance)
         app.sources_refreshed.connect(txhistory.refresh_balance)
         txhistory.view_in_wot.connect(app.view_in_wot)
         txhistory.view.spin_page.valueChanged.connect(model.change_page)
-        transfer.accepted.connect(view.clear)
-        transfer.rejected.connect(view.clear)
+        controller.accepted.connect(view.clear)
+        controller.rejected.connect(view.clear)
         return txhistory
 
     def refresh_minimum_maximum(self):
