@@ -17,7 +17,7 @@ from sakia.data.entities import Transaction
 from sakia.constants import MAX_CONFIRMATIONS
 from sakia.data.processors import BlockchainProcessor
 from .sql_adapter import TxHistorySqlAdapter
-from sakia.data.repositories import TransactionsRepo, DividendsRepo
+from sakia.data.repositories import TransactionsRepo, DividendsRepo, SourcesRepo
 from sakia.data.entities.transaction import STOPLINE_HASH
 
 
@@ -39,6 +39,7 @@ class HistoryTableModel(QAbstractTableModel):
         "block_number",
         "txhash",
         "raw_data",
+        "conditions",
     )
 
     columns_to_sql = {
@@ -81,6 +82,7 @@ class HistoryTableModel(QAbstractTableModel):
         self.sql_adapter = TxHistorySqlAdapter(self.app.db.conn)
         self.transactions_repo = TransactionsRepo(self.app.db.conn)
         self.dividends_repo = DividendsRepo(self.app.db.conn)
+        self.sources_repo = SourcesRepo(self.app.db.conn)
         self.current_page = 0
         self.ts_from = ts_from
         self.ts_to = ts_to
@@ -137,6 +139,20 @@ class HistoryTableModel(QAbstractTableModel):
         )
 
     def change_transfer(self, transfer):
+        # capture sources associated with tx
+        sources = self.sources_repo.get_all(
+            currency=transfer.currency, identifier=transfer.sha_hash
+        )
+        # capture complex conditions
+        sources_conditions = [
+            source.conditions
+            for source in sources
+            if "&&" in source.conditions or "||" in source.conditions
+        ]
+        transfer.conditions = (
+            sources_conditions[0] if len(sources_conditions) > 0 else None
+        )
+
         for i, data in enumerate(self.transfers_data):
             if (
                 data[HistoryTableModel.columns_types.index("txhash")]
@@ -232,6 +248,7 @@ class HistoryTableModel(QAbstractTableModel):
             block_number,
             transfer.sha_hash,
             transfer,
+            transfer.conditions,
         )
 
     def data_sent(self, transfer):
@@ -267,6 +284,7 @@ class HistoryTableModel(QAbstractTableModel):
             block_number,
             transfer.sha_hash,
             transfer,
+            transfer.conditions,
         )
 
     def data_dividend(self, dividend):
@@ -299,6 +317,7 @@ class HistoryTableModel(QAbstractTableModel):
             block_number,
             "",
             dividend,
+            dividend.conditions,
         )
 
     def init_transfers(self):
@@ -312,7 +331,7 @@ class HistoryTableModel(QAbstractTableModel):
                     pubkey=self.connection.pubkey,
                     sha_hash=data[4],
                 )
-
+                transfer.conditions = data[7]
                 if transfer.state != Transaction.DROPPED:
                     if data[4] == STOPLINE_HASH:
                         self.transfers_data.append(self.data_stopline(transfer))
@@ -327,6 +346,7 @@ class HistoryTableModel(QAbstractTableModel):
                     pubkey=self.connection.pubkey,
                     block_number=data[5],
                 )
+                dividend.conditions = data[7]
                 self.transfers_data.append(self.data_dividend(dividend))
         self.endResetModel()
 
@@ -334,7 +354,7 @@ class HistoryTableModel(QAbstractTableModel):
         return len(self.transfers_data)
 
     def columnCount(self, parent):
-        return len(HistoryTableModel.columns_types) - 6
+        return 4
 
     def sort(self, main_column, order):
         self.main_column_id = self.columns_types[main_column]
@@ -374,7 +394,9 @@ class HistoryTableModel(QAbstractTableModel):
         block_data = self.transfers_data[row][
             HistoryTableModel.columns_types.index("block_number")
         ]
-
+        conditions_data = self.transfers_data[row][
+            HistoryTableModel.columns_types.index("conditions")
+        ]
         if state_data == Transaction.VALIDATED and block_data:
             current_confirmations = (
                 self.blockchain_processor.current_buid(self.app.currency).number
@@ -425,9 +447,12 @@ class HistoryTableModel(QAbstractTableModel):
                 elif state_data == Transaction.REFUSED:
                     font.setItalic(True)
                 elif state_data == Transaction.TO_SEND:
-                    font.setBold(True)
+                    font.setItalic(True)
                 else:
                     font.setItalic(False)
+            # if special lock conditions on a source coming from this transaction...
+            if conditions_data is not None:
+                font.setUnderline(True)
             return font
 
         if role == Qt.ForegroundRole:
@@ -441,9 +466,7 @@ class HistoryTableModel(QAbstractTableModel):
                     color = QColor(Qt.darkRed)
                 elif state_data == HistoryTableModel.DIVIDEND:
                     color = QColor(Qt.darkBlue)
-            if state_data == Transaction.AWAITING or (
-                state_data == Transaction.VALIDATED and current_confirmations == 0
-            ):
+            if state_data == Transaction.AWAITING:
                 color = QColor("#ffb000")
             if color:
                 if self.app.parameters.dark_theme:
