@@ -6,6 +6,7 @@ from sakia.data.processors import (
     ConnectionsProcessor,
     ContactsProcessor,
 )
+from sakia.money.base_referential import BaseReferential
 
 
 @attr.s()
@@ -33,27 +34,30 @@ class TransferModel(QObject):
         self._connections_processor = ConnectionsProcessor.instanciate(self.app)
         self._contacts_processor = ContactsProcessor.instanciate(self.app)
 
-    def rel_to_quant(self, rel_value):
+    def referential_to_quantitative(self, value):
         """
-        Get the quantitative value of a relative amount
-        :param float rel_value:
+        Get the quantitative value of a referential amount
+        :param float value:
         :rtype: int
         """
-        dividend, base = self._blockchain_processor.last_ud(self.connection.currency)
-        amount = rel_value * dividend
+        referential = self.app.current_ref(
+            0, self.app.currency, self.app
+        )  # type: BaseReferential
+        referential.set_diff_referential(value)
         # amount is rounded to the nearest power of 10 depending of last ud base
         # rounded = int(pow(10, base) * round(float(amount) / pow(10, base)))
-        return int(amount) / 100
+        return int(referential.amount)
 
-    def quant_to_rel(self, amount):
+    def quantitative_to_referential(self, value):
         """
-        Get the relative value of a given amount
-        :param int amount:
+        Get the referential value of a given amount
+        :param int value:
         :rtype: float
         """
-        dividend, base = self._blockchain_processor.last_ud(self.connection.currency)
-        relative = amount * 100 / dividend
-        return relative
+        referential = self.app.current_ref(
+            value * 100, self.app.currency, self.app
+        )  # type: BaseReferential
+        return referential.differential()
 
     def wallet_value(self):
         """
