@@ -159,14 +159,14 @@ class TransferView(QWidget, Ui_TransferMoneyWidget):
         self.spinbox_amount.setValue(amount)
         self.spinbox_amount.blockSignals(False)
 
-    def change_relative_amount(self, relative):
+    def change_referential_amount(self, referential_amount):
         """
         Change the quantitative amount with signals blocks
-        :param relative:
+        :param referential_amount:
         """
-        self.spinbox_relative.blockSignals(True)
-        self.spinbox_relative.setValue(relative)
-        self.spinbox_relative.blockSignals(False)
+        self.spinbox_referential.blockSignals(True)
+        self.spinbox_referential.setValue(referential_amount)
+        self.spinbox_referential.blockSignals(False)
 
     def set_spinboxes_parameters(self, max_quant, max_rel):
         """
@@ -176,7 +176,7 @@ class TransferView(QWidget, Ui_TransferMoneyWidget):
         :param float max_rel:
         """
         self.spinbox_amount.setMaximum(max_quant)
-        self.spinbox_relative.setMaximum(max_rel)
+        self.spinbox_referential.setMaximum(max_rel)
 
     def refresh_labels(self, total_text):
         """
